[−][src]Struct irc_rust::prefix::Prefix
Message prefix containing a name (servername or nickname) and optional user and host. If the user and host are set the name is semantically seen as the nickname.
Methods
impl Prefix[src]
pub fn new(raw: &str) -> Prefix[src]
Create a new Prefix from the given string. Expects the string to be a valid prefix string.
pub fn builder(name: &str) -> PrefixBuilder[src]
pub fn name(&self) -> &str[src]
pub fn host(&self) -> Option<&str>[src]
pub fn user(&self) -> Option<&str>[src]